==> calligra_3.0.1.orig.tar.xz: calligra-3.0.1/libs/text/KoReplaceStrategy.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOREPLACESTRATEGY_H
#define KOREPLACESTRATEGY_H

#include "KoFindStrategyBase.h"

class QWidget;
class KReplaceDialog;

/**
 * Stratagy used for implementing replace
 */
class KoReplaceStrategy : public KoFindStrategyBase
{
public:
    explicit KoReplaceStrategy(QWidget *parent);
    virtual ~KoReplaceStrategy();

    /// reimplmented
    KFindDialog *dialog() const;

    /// reimplmented
    virtual void reset();

    /// reimplmented
    virtual void displayFinalDialog();

    /// reimplmented
    virtual bool foundMatch(QTextCursor &cursor, FindDirection *findDirection);

private:
    KReplaceDialog *m_dialog;
    int m_replaced;
};

#endif /* KOREPLACESTRATEGY_H */

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/libs/text/KoReplaceStrategy.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOREPLACESTRATEGY_H
#define KOREPLACESTRATEGY_H

#include "KoFindStrategyBase.h"

class QWidget;
class KReplaceDialog;

/**
 * Strategy used for implementing replace
 */
class KoReplaceStrategy : public KoFindStrategyBase
{
public:
    explicit KoReplaceStrategy(QWidget *parent);
    ~KoReplaceStrategy() override;

    /// reimplmented
    KFindDialog *dialog() const override;

    /// reimplmented
    void reset() override;

    /// reimplmented
    void displayFinalDialog() override;

    /// reimplmented
    bool foundMatch(QTextCursor &cursor, FindDirection *findDirection) override;

private:
    KReplaceDialog *m_dialog;
    int m_replaced;
};

#endif /* KOREPLACESTRATEGY_H */
